@@ -30,6 +30,8 @@ class Ks3Oss:
         if content_type == "string":
             ret = k.set_contents_from_string(**kwargs)
         elif content_type == "file":
+            ret = k.set_contents_from_file(**kwargs)
+        elif content_type == "filename":
             ret = k.set_contents_from_filename(**kwargs)
         elif content_type == "network":
             ret = k.fetch_object(**kwargs)
