@@ -29,7 +29,7 @@ define("profile", default="profiles.config", type=str, help="配置文件")
 define("port", default="8080", type=int, help="服务监听端口")
 define("handler_path", default="handlers", type=str, help="处理器文件存储路径")
 define("echo_sql", default=True, type=bool, help="是否启用SQL输出")
-define("async_enable", default=True, type=bool, help="是否启用异步")
+define("async_enable", default=False, type=bool, help="是否启用异步")
 define("max_limit", default=500, type=int, help="单次查询最大数量")
 define("eureka_enable", default=False, type=bool, help="是否启用eureka")
 define("eureka_server", default="", type=str, help="eureka server地址")
